@@ -38,7 +38,7 @@
 #include <stdlib.h>
 #include <sys/stat.h>
 
-const char *plugin_version="LiVES mkv decoder version 1.0";
+const char *plugin_version="LiVES mkv decoder version 1.2";
 
 #ifdef HAVE_AV_CONFIG_H
 #undef HAVE_AV_CONFIG_H
@@ -1010,6 +1010,7 @@ static void matroska_execute_seekhead(const lives_clip_data_t *cdata) {
       (matroska->ctx->flags & AVFMT_FLAG_IGNIDX))
       return;*/
 
+
   for (i = 0; i < seekhead_list->nb_elem; i++) {
     if (seekhead[i].pos <= before_pos)
       continue;
@@ -1024,6 +1025,7 @@ static void matroska_execute_seekhead(const lives_clip_data_t *cdata) {
       break;
   }
 
+
 }
 
 
@@ -1525,7 +1527,7 @@ static int lives_mkv_read_header(lives_clip_data_t *cdata) {
       if (track->default_duration)
 	st->avg_frame_rate = av_d2q(1000000000.0/track->default_duration, INT_MAX);
 
-      if (cdata->fps==0.) cdata->fps=st->avg_frame_rate.num/st->avg_frame_rate.den;
+      if (cdata->fps==0.) cdata->fps=(float)st->avg_frame_rate.num/(float)st->avg_frame_rate.den;
 
       /*
 	if (track->video.stereo_mode && track->video.stereo_mode < MATROSKA_VIDEO_STEREO_MODE_COUNT)
@@ -1554,7 +1556,6 @@ static int lives_mkv_read_header(lives_clip_data_t *cdata) {
     return -5;
   }
 
-
   /* Parse the CUES now since we need the index data to seek. */
   if (priv->matroska.cues_parsing_deferred) {
     matroska_parse_cues(cdata);
@@ -2575,7 +2576,6 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
       idx=matroska_read_seek(cdata,target_pts);
       nextframe=dts_to_frame(cdata,idx->dts);
       avcodec_flush_buffers (priv->ctx);
-
 #ifdef DEBUG_KFRAMES
       if (idx!=NULL) printf("got kframe %ld for frame %ld\n",dts_to_frame(cdata,idx->dts),tframe);
 #endif
@@ -2590,6 +2590,7 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
 
     // do this until we reach target frame //////////////
 
+
     do {
 
       got_picture=FALSE;
@@ -2614,6 +2615,7 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
       }
 
       nextframe++;
+
       if (nextframe>cdata->nframes) return FALSE;
     } while (nextframe<=tframe);
 
