@@ -55,6 +55,9 @@ gchar *lives_fx_cat_to_text(lives_fx_cat_t cat, gboolean plural) {
   case LIVES_FX_CAT_GENERATOR:
     if (!plural) return (g_strdup(_("generator")));
     else return (g_strdup(_("Generators")));
+  case LIVES_FX_CAT_DATA_GENERATOR:
+    if (!plural) return (g_strdup(_("data generator")));
+    else return (g_strdup(_("Data Generators")));
   case LIVES_FX_CAT_TRANSITION:
     if (!plural) return (g_strdup(_("transition")));
     else return (g_strdup(_("Transitions")));
@@ -73,7 +76,7 @@ gchar *lives_fx_cat_to_text(lives_fx_cat_t cat, gboolean plural) {
   case LIVES_FX_CAT_SPLITTER:
     if (!plural) return (g_strdup(_("splitter")));
     else return (g_strdup(_("Splitters")));
-  case LIVES_FX_CAT_CONVERTOR:
+  case LIVES_FX_CAT_CONVERTER:
     if (!plural) return (g_strdup(_("converter")));
     else return (g_strdup(_("Converters")));
   case LIVES_FX_CAT_ANALYSER:
@@ -105,7 +108,7 @@ gchar *lives_fx_cat_to_text(lives_fx_cat_t cat, gboolean plural) {
     else return (g_strdup(_("Video analysers")));
   case LIVES_FX_CAT_AUDIO_ANALYSER:
     if (!plural) return (g_strdup(_("audio analyser")));
-    else return (g_strdup(_("Audio analysers")));
+    else return (g_strdup(_("Audio Analysers")));
 
 
   default:
@@ -490,7 +493,7 @@ gboolean do_effect(lives_rfx_t *rfx, gboolean is_preview) {
       
       init_clipboard();
       
-      w_memcpy(clipboard,cfile,sizeof(file));
+      lives_memcpy(clipboard,cfile,sizeof(file));
       cfile->is_loaded=TRUE;
       mainw->suppress_dprint=TRUE;
       mainw->only_close=TRUE;
@@ -559,7 +562,7 @@ lives_render_error_t realfx_progress (gboolean reset) {
   static int i;
   GError *error=NULL;
   gchar oname[PATH_MAX];
-  GdkPixbuf *pixbuf;
+  LiVESPixbuf *pixbuf;
   gchar *com;
   gint64 frameticks;
   weed_plant_t *layer;
@@ -617,7 +620,7 @@ lives_render_error_t realfx_progress (gboolean reset) {
   else if (cfile->img_type==IMG_TYPE_PNG&&layer_palette!=WEED_PALETTE_RGBA32) 
     convert_layer_palette(layer,WEED_PALETTE_RGBA32,0);
 
-  if (resize_instance==NULL) resize_layer(layer,cfile->hsize,cfile->vsize,GDK_INTERP_HYPER);
+  if (resize_instance==NULL) resize_layer(layer,cfile->hsize,cfile->vsize,LIVES_INTERP_BEST);
   pixbuf=layer_to_pixbuf(layer);
   weed_plant_free(layer);
 
