@@ -48,7 +48,6 @@ POSSIBILITY OF SUCH DAMAGES.
 // Have fun, and let's fight for Free Speech, Open Media and True Creativity !
 // - Salsaman
 
-
 #ifndef HAS_LIVES_MAIN_H
 #define HAS_LIVES_MAIN_H
 
@@ -59,27 +58,12 @@ POSSIBILITY OF SUCH DAMAGES.
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
-#ifdef IS_LINUX_GNU
+#ifdef GDK_WINDOWING_X11
 #define USE_X11
-#endif
-
-#ifdef IS_DARWIN
-#define USE_X11
-#endif
-
-#ifdef USE_X11
 
 // needed for GDK_WINDOW_XID - for fileselector preview
-
-// needed for XMapWindow, GDK_WINDOW_XDISPLAY, GDK_WINDOW_XID, GTK_SOCKET
-// for external window capture
-
 // needed for gdk_x11_screen_get_window_manager_name()
 
-#if GTK_CHECK_VERSION(3,0,0)
-#include <gtk/gtkx.h>
-#endif
-
 #include <gdk/gdkx.h>
 #endif
 
@@ -210,7 +194,7 @@ typedef struct {
   GtkWidget *cancel_button;
   GtkWidget *scrolledwindow;
   guint frames_done;
-} process;
+} xprocess;
 
 
 
@@ -417,7 +401,7 @@ typedef struct {
   gint rowstride;
 
   /// the processing window
-  process *proc_ptr;
+  xprocess *proc_ptr;
 
   gchar handle[256];
   gint ohsize;
@@ -590,6 +574,8 @@ typedef struct {
   gboolean has_pulse_audio;
   gboolean has_xwininfo;
   gboolean has_gdb;
+  gboolean has_gconftool_2;
+  gboolean has_xdg_screensaver;
 
   /// home directory - default location for config file - locale encoding
   gchar home_dir[PATH_MAX];
@@ -601,8 +587,10 @@ typedef struct {
   gboolean has_encoder_plugins;
 
   gboolean has_python;
+  guint64 python_version;
 
   gshort cpu_bits;
+  
 
   gchar *myname_full;
   gchar *myname;
@@ -720,7 +708,7 @@ typedef enum {
 // some useful functions
 
 // interface.c
-process* create_processing (const gchar *text);
+xprocess* create_processing (const gchar *text);
 void add_to_winmenu(void);
 void remove_from_winmenu(void);
 void make_play_window(void);
@@ -926,8 +914,8 @@ void load_preview_image(gboolean update_always);
 gboolean pull_frame(weed_plant_t *layer, const gchar *image_ext, weed_timecode_t tc);
 gboolean pull_frame_at_size (weed_plant_t *layer, const gchar *image_ext, weed_timecode_t tc, 
 			     int width, int height, int target_palette);
-GdkPixbuf *pull_gdk_pixbuf_at_size(gint clip, gint frame, const gchar *image_ext, weed_timecode_t tc, 
-				   gint width, gint height, GdkInterpType interp);
+LiVESPixbuf *pull_lives_pixbuf_at_size(int clip, int frame, const char *image_ext, weed_timecode_t tc, 
+				       int width, int height, LiVESInterpType interp);
 GError * lives_pixbuf_save(GdkPixbuf *pixbuf, gchar *fname, lives_image_type_t imgtype, 
 			   int quality, gboolean do_chmod, GError **gerrorptr);
 
@@ -1004,6 +992,7 @@ gchar *get_dir(const gchar *filename);
 void get_basename(gchar *filename);
 void get_filename(gchar *filename, gboolean strip_dir);
 gchar *get_extension(const gchar *filename);
+guint64 get_version_hash(const gchar *exe, const gchar *sep, int piece);
 void d_print(const gchar *text);
 void init_clipboard(void);
 gboolean cache_file_contents(const gchar *filename);
@@ -1100,7 +1089,7 @@ void set_sel_label (GtkWidget *label);
 void clear_mainw_msg (void);
 gint get_token_count (const gchar *string, int delim);
 GdkPixmap* gdk_pixmap_copy (GdkPixmap *pixmap);
-GdkPixbuf *gdk_pixbuf_new_blank(gint width, gint height, int palette);
+LiVESPixbuf *lives_pixbuf_new_blank(int width, int height, int palette);
 void get_border_size (GtkWidget *win, gint *bx, gint *by);
 gchar *g_strappend (gchar *string, gint len, const gchar *newbit);
 GList *g_list_append_unique(GList *xlist, const gchar *add);
@@ -1108,7 +1097,7 @@ void find_when_to_stop (void);
 gint calc_new_playback_position(gint fileno, gint64 otc, gint64 *ntc);
 void calc_aframeno(gint fileno);
 void minimise_aspect_delta (gdouble allowed_aspect,gint hblock,gint vblock,gint hsize,gint vsize,gint *width,gint *height);
-GdkInterpType get_interp_value(gshort quality);
+LiVESInterpType get_interp_value(gshort quality);
 GList *g_list_move_to_first(GList *list, GList *item) WARN_UNUSED;
 GList *g_list_delete_string(GList *, char *string) WARN_UNUSED;
 GList *g_list_copy_strings(GList *list);
@@ -1164,7 +1153,14 @@ void add_fill_to_box (GtkBox *);
 void refresh_rte_window (void);
 
 // effects-weed.c
-void *w_memcpy  (void *dest, const void *src, size_t n);
+void * lives_malloc(size_t size);
+void *lives_memcpy(void *dest, const void *src, size_t n);
+void *lives_memset(void *s, int c, size_t n);
+void lives_free(void *ptr); ///< calls mainw->free_fn
+
+/// values of mainw->free_fn
+void lives_free_normal(void *ptr);
+void lives_free_with_check(gpointer ptr); ///< checks if ptr is mainw->do_not_free, otherwise calls lives_free_normal()
 
 // pangotext.c
 gboolean subtitles_init(file *sfile, char * fname, lives_subtitle_type_t);
@@ -1218,7 +1214,6 @@ void on_open_fw_activate (GtkMenuItem *menuitem, gpointer format);
 gchar *dummychar;
 
 #define LIVES_NO_DEBUG
-
 #ifndef LIVES_DEBUG
 #ifndef LIVES_NO_DEBUG
 #define LIVES_DEBUG(x)      fprintf(stderr, "LiVES debug: %s\n", x)
