@@ -25,20 +25,24 @@
 /// >10**8 is not recommended, since we sometimes store seconds in a gdouble
 #define U_SEC 100000000.
 #define U_SECL (gint64)100000000
-#define U_SEC_RATIO (U_SECL/1000000) ///< how many U_SECs (ticks) in a microsecond
+#define U_SEC_RATIO (U_SECL/1000000) ///< how many U_SECs (ticks) in a microsecond [default 100]
 
 // parameters for resizing the image frames, and for capture
 // TODO - make prefs
 #define V_RESIZE_ADJUST 36
 #define H_RESIZE_ADJUST 22
 
-/// vert displacement up from center for sepwin (actual value is half this)
-#define SEPWIN_VADJUST 200
+// sepwin/screen size safety margins in pixels
+#define DSIZE_SAFETY_H 100
+#define DSIZE_SAFETY_V 100
 
 /// default size for generators
 #define DEF_GEN_WIDTH 640
 #define DEF_GEN_HEIGHT 480
 
+// height of preview widgets in sepwin
+#define PREVIEW_BOX_HT 100
+
 /// number of function keys
 #define FN_KEYS 12
 
@@ -222,7 +226,7 @@ typedef struct {
   gint audio_end;
 
   gboolean ext_playback; ///< using external video playback plugin
-  gboolean ext_keyboard; ///< keyboard codes must be polled from video playback plugin
+  volatile gboolean ext_keyboard; ///< keyboard codes must be polled from video playback plugin
 
   gint ptr_x;
   gint ptr_y;
@@ -286,9 +290,11 @@ typedef struct {
   unsigned int foreign_id;
   GdkColormap *foreign_cmap;
   GdkPixmap *foreign_map;
+  GdkWindow *foreign_window;
   gint foreign_width;
   gint foreign_height;
   gint foreign_bpp;
+  gchar *foreign_visual;
 
   /// some VJ effects
   gboolean nervous;
@@ -413,9 +419,10 @@ typedef struct {
 
   gboolean osc_auto; ///< bypass user choices automatically
 
-  /// encode width and height set externally
+  /// encode width, height and fps set externally
   gint osc_enc_width;
   gint osc_enc_height;
+  float osc_enc_fps;
 
 
   /// fixed fps playback; usually fixed_fpsd==0.
@@ -516,11 +523,10 @@ typedef struct {
 
   gint new_blend_file;
 
-  // Widgets  -- TODO - move into sub struct mainw->widgets->*
-  GdkNativeWindow xwin;
   GtkWidget *frame1;
   GtkWidget *frame2;
   GtkWidget *playframe;
+  GtkWidget *pl_eventbox;
   GdkPixbuf *imframe;
   GdkPixbuf *camframe;
   GdkPixbuf *imsep;
@@ -656,6 +662,7 @@ typedef struct {
 
   /// for the fileselection preview
   GtkWidget *fs_playarea;
+  GtkWidget *fs_playalign;
   GtkWidget *fs_playframe;
 
   /// for the framedraw special widget - TODO - use a sub-struct
@@ -694,7 +701,7 @@ typedef struct {
   GtkWidget *image274;
   GtkWidget *play_window;
   weed_plant_t *frame_layer;
-  GtkWidget *plug1;
+  GtkWidget *plug;
   gulong pw_exp_func;
   gboolean pw_exp_is_blocked;
 
@@ -1017,6 +1024,8 @@ typedef struct {
 
   guint64 next_ds_warn_level; ///< current disk space warning level for the tempdir
 
+  float sepwin_scale;
+
 } mainwindow;
 
 GdkCursor *hidden_cursor;
