@@ -23,8 +23,8 @@
 #define MT_PLAY_WIDTH_SMALL 320
 #define MT_PLAY_HEIGHT_SMALL 216
 
-#define MT_PLAY_WIDTH_EXP 480
-#define MT_PLAY_HEIGHT_EXP 360
+#define MT_PLAY_WIDTH_EXP 432
+#define MT_PLAY_HEIGHT_EXP 324
 
 #define MT_CTX_WIDTH 320
 #define MT_CTX_HEIGHT 220
@@ -292,6 +292,7 @@ struct _mt {
   GtkWidget *fx_ibefore_button;
   GtkWidget *fx_iafter_button;
   GtkWidget *cback_audio;
+  GtkWidget *aload_subs;
   GtkWidget *load_vals;
   GtkWidget *change_vals;
   GtkWidget *aparam_separator;
@@ -348,13 +349,13 @@ struct _mt {
   GtkWidget *insa_checkbutton;
   GtkWidget *snapo_checkbutton;
 
-  GtkObject *spinbutton_in_adj;
-  GtkObject *spinbutton_out_adj;
+  GObject *spinbutton_in_adj;
+  GObject *spinbutton_out_adj;
 
   GdkCursor *cursor;
 
-  GtkObject *hadjustment;
-  GtkObject *node_adj;
+  GObject *hadjustment;
+  GObject *node_adj;
 
   GList *audio_draws; ///< list of audio boxes, 0 == backing audio, 1 == track 0 audio, etc.
 
@@ -363,7 +364,7 @@ struct _mt {
 
   GtkAccelGroup *accel_group;
   GList *video_draws; ///< list of video timeline eventboxes, in layer order
-  GtkObject *vadjustment;
+  GObject *vadjustment;
 
   GdkDisplay *display;
 
