@@ -211,12 +211,7 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
 	   pulsed->playing_file=new_file;
 	   pulsed->audio_ticks=mainw->currticks;
 	   pulsed->frames_written=0;
-	   pulsed->aPlayPtr->data=g_try_realloc(pulsed->aPlayPtr->data,nbytes*100);
-	   if (pulsed->aPlayPtr->data!=NULL) {
-	     memset(pulsed->aPlayPtr->data,0,nbytes*100);
-	     pulsed->aPlayPtr->size=nbytes*100;
-	   }
-	   else pulsed->aPlayPtr->size=0;
+	   pulsed->usec_start=0;
 	 }
 	 g_free(filename);
        }
@@ -226,6 +221,7 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
        pulsed->fd=-1;
        if (pulsed->aPlayPtr->data!=NULL) g_free(pulsed->aPlayPtr->data);
        pulsed->aPlayPtr->data=NULL;
+       pulsed->aPlayPtr->max_size=0;
        pulsed->aPlayPtr->size=0;
        pulsed->playing_file=-1;
        break;
@@ -239,6 +235,7 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
        pulsed->seek_pos=seek;
        pulsed->audio_ticks=mainw->currticks;
        pulsed->frames_written=0;
+       pulsed->usec_start=0;
        break;
      default:
        msg->data=NULL;
@@ -251,15 +248,6 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
 
    if (pulsed->chunk_size!=nbytes) pulsed->chunk_size = nbytes;
 
-   if (nbytes*100>pulsed->aPlayPtr->size) {
-     pulsed->aPlayPtr->data=g_try_realloc(pulsed->aPlayPtr->data,nbytes*100);
-     if (pulsed->aPlayPtr->data!=NULL) {
-       memset(pulsed->aPlayPtr->data,0,nbytes*100);
-       pulsed->aPlayPtr->size=nbytes*100;
-     }
-     else pulsed->aPlayPtr->size=0;
-   }
-
    pulsed->state=pa_context_get_state(pulsed->con);
 
    if (pulsed->state==PA_CONTEXT_READY) {
@@ -291,7 +279,7 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
      }
 
      if (G_LIKELY(pulseFramesAvailable>0&&(pulsed->read_abuf>-1||
-					   (pulsed->aPlayPtr!=NULL&&pulsed->aPlayPtr->data!=NULL
+					   (pulsed->aPlayPtr!=NULL
 					    &&pulsed->in_achans>0)))) {
 
        if (mainw->playing_file>-1&&pulsed->read_abuf>-1) {
@@ -335,6 +323,16 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
 	     // rewind by in_bytes
 	     lseek(pulsed->fd,pulsed->seek_pos,SEEK_SET);
 	   }
+	   if G_UNLIKELY((in_bytes>pulsed->aPlayPtr->max_size && !(*pulsed->cancelled) && ABS(shrink_factor)<=100.f)) {
+	     pulsed->aPlayPtr->data=g_try_realloc(pulsed->aPlayPtr->data,in_bytes);
+	     if (pulsed->aPlayPtr->data!=NULL) {
+	       memset(pulsed->aPlayPtr->data,0,in_bytes);
+	       pulsed->aPlayPtr->max_size=in_bytes;
+	     }
+	   }
+	   else {
+	     pulsed->aPlayPtr->max_size=0;
+	   }
 	   if (pulsed->mute||pulsed->aPlayPtr->data==NULL) {
 	     if (shrink_factor>0.f) pulsed->seek_pos+=in_bytes;
 	     if (pulsed->seek_pos>=pulsed->seek_end) {
@@ -498,7 +496,7 @@ static void pulse_audio_write_process (pa_stream *pstream, size_t nbytes, void *
 	       if (!pulsed->is_paused) pulsed->frames_written+=nframes;
 	       return;
 	     }
-	     w_memcpy(buffer,pulsed->sound_buffer+offs,xbytes);
+	     lives_memcpy(buffer,pulsed->sound_buffer+offs,xbytes);
 	     offs+=xbytes;
 	     needs_free=TRUE;
 	   }
@@ -565,8 +563,8 @@ void pulse_flush_read_data(pulse_driver_t *pulsed, size_t rbytes, void *data) {
 
   if (!gbuf) return;
 
-  w_memcpy(gbuf,prbuf,prb-rbytes);
-  if (rbytes>0) w_memcpy(gbuf+(prb-rbytes)/sizeof(short),data,rbytes);
+  lives_memcpy(gbuf,prbuf,prb-rbytes);
+  if (rbytes>0) lives_memcpy(gbuf+(prb-rbytes)/sizeof(short),data,rbytes);
 
   frames_out=(size_t)((gdouble)((prb/(pulsed->in_asamps>>3)/pulsed->in_achans))/out_scale+.5);
 
@@ -637,7 +635,7 @@ static void pulse_audio_read_process (pa_stream *pstream, size_t nbytes, void *a
 
   if (prb<PULSE_READ_BYTES&&(mainw->rec_samples==-1||frames_out<mainw->rec_samples)) {
     // buffer until we have enough
-    w_memcpy(&prbuf[prb-rbytes],data,rbytes);
+    lives_memcpy(&prbuf[prb-rbytes],data,rbytes);
     pa_stream_drop(pulsed->pstream);
     return;
   }
@@ -701,6 +699,7 @@ int pulse_audio_init(void) {
   pulsed.aPlayPtr=(audio_buffer_t *)g_malloc(sizeof(audio_buffer_t));
   pulsed.aPlayPtr->data=NULL;
   pulsed.aPlayPtr->size=0;
+  pulsed.aPlayPtr->max_size=0;
   gettimeofday(&pulsed.last_reconnect_attempt, 0);
   pulsed.in_achans=2;
   pulsed.out_achans=2;
@@ -830,9 +829,9 @@ int pulse_driver_activate(pulse_driver_t *pdriver) {
 
 #ifdef PA_STREAM_START_UNMUTED
     pa_stream_connect_playback(pdriver->pstream,NULL,&pa_battr,
-			       (pa_stream_flags_t)(PA_STREAM_START_UNMUTED|PA_STREAM_ADJUST_LATENCY),&out_vol,NULL);
+			       (pa_stream_flags_t)(PA_STREAM_START_UNMUTED|PA_STREAM_ADJUST_LATENCY|PA_STREAM_INTERPOLATE_TIMING|PA_STREAM_AUTO_TIMING_UPDATE),&out_vol,NULL);
 #else
-    pa_stream_connect_playback(pdriver->pstream,NULL,&pa_battr,(pa_stream_flags_t)(PA_STREAM_ADJUST_LATENCY),&out_vol,NULL);
+    pa_stream_connect_playback(pdriver->pstream,NULL,&pa_battr,(pa_stream_flags_t)(PA_STREAM_ADJUST_LATENCY|PA_STREAM_INTERPOLATE_TIMING|PA_STREAM_AUTO_TIMING_UPDATE),&out_vol,NULL);
 #endif
 
     while (pa_stream_get_state(pdriver->pstream)!=PA_STREAM_READY) {
@@ -843,6 +842,7 @@ int pulse_driver_activate(pulse_driver_t *pdriver) {
     // set read callback
     pdriver->audio_ticks=0;
     pdriver->frames_written=0;
+    pdriver->usec_start=0;
     prb=0;
 
     pa_stream_set_read_callback(pdriver->pstream,pulse_audio_read_process,pdriver);
@@ -906,8 +906,16 @@ gint64 lives_pulse_get_time(pulse_driver_t *pulsed, gboolean absolute) {
     lives_alarm_clear(alarm_handle);
   }
 
+#ifdef USE_PA_INTERP_TIME
+  {
+    pa_usec_t usec;
+    pa_stream_get_time(pulsed->pstream,&usec);
+    return pulsed->audio_ticks*absolute+(gint64)((usec-pulsed->usec_start)*U_SEC_RATIO);
+  }
+#else
   if (pulsed->is_output) return pulsed->audio_ticks*absolute+(gint64)(frames_written/(gdouble)pulsed->out_arate*U_SEC);
   return pulsed->audio_ticks*absolute+(gint64)(frames_written/(gdouble)afile->arate*U_SEC);
+#endif
 
 }
 
